@@ -42,17 +42,25 @@ __all__ = [
 # for a list of the end points and marketplace IDs
 
 MARKETPLACES = {
+    "AE": "https://mws.amazonservices.ae",  # A2VIGQ35RCS4UG
+    "AU": "https://mws.amazonservices.com.au",  # A39IBJ37TRP1C6
+    "BR": "https://mws.amazonservices.com",  # A2Q3Y263D00KWC
     "CA": "https://mws.amazonservices.ca",  # A2EUQ1WTGCTBG2
-    "US": "https://mws.amazonservices.com",  # ATVPDKIKX0DER",
     "DE": "https://mws-eu.amazonservices.com",  # A1PA6795UKMFR9
+    "EG": "https://mws-eu.amazonservices.com",  # ARBP9OOSHTCHU
     "ES": "https://mws-eu.amazonservices.com",  # A1RKKUPIHCS9HS
     "FR": "https://mws-eu.amazonservices.com",  # A13V1IB3VIYZZH
+    "GB": "https://mws-eu.amazonservices.com",  # A1F83G8C2ARO7P
     "IN": "https://mws.amazonservices.in",  # A21TJRUUN4KGV
     "IT": "https://mws-eu.amazonservices.com",  # APJ6JRA9NG5V4
-    "UK": "https://mws-eu.amazonservices.com",  # A1F83G8C2ARO7P
     "JP": "https://mws.amazonservices.jp",  # A1VC38T7YXB528
-    "CN": "https://mws.amazonservices.com.cn",  # AAHKV2X7AFYLW
     "MX": "https://mws.amazonservices.com.mx",  # A1AM78C64UM0Y8
+    "NL": "https://mws-eu.amazonservices.com",  # A1805IZSGTT6HS
+    "SA": "https://mws-eu.amazonservices.com",  # A17E79C6D8DWNP
+    "SG": "https://mws-fe.amazonservices.com",  # A19VAU5U5O7RUS
+    "TR": "https://mws-eu.amazonservices.com",  # A33AVAJ2PDY3EV
+    "UK": "https://mws-eu.amazonservices.com",  # A1F83G8C2ARO7P - GB alias
+    "US": "https://mws.amazonservices.com",  # ATVPDKIKX0DER
 }
 
 
@@ -225,7 +233,7 @@ class MWS(object):
             description=request_description,
             signature=quote(signature),
         )
-        headers = {'User-Agent': 'python-amazon-mws/0.8.3 (Language=Python)'}
+        headers = {'User-Agent': 'python-amazon-mws/0.8.7 (Language=Python)'}
         headers.update(kwargs.get('extra_headers', {}))
 
         try:
